type token =
    LPAREN
  | RPAREN
  | LBRACKET
  | RBRACKET
  | PERIOD
  | COMMA
  | ACTIONOVERRIDE
  | HASH
  | NOT
  | EOF
  | IF
  | THEN
  | END
  | RESPONSE
  | ANYONE
  | STRING of (string)
  | SYMBOL of (string)
  | TILDE_STRING of (string)
  | INTEGER of (Int32.t)
  | TRANS_REF of (Int32.t)

open Parsing
# 2 "src/bafparser.mly"
open Util
open Ids
open Bcs
open Load

(*** input handle ***)

(*** Error handling ***)

type bafarg = 
  BA_Symbol of string
| BA_Integer of Int32.t
| BA_String of string
| BA_Bracket of bracket_arg list
| BA_Compound of string * bafarg
and bracket_arg =
  Bracket_Integer of Int32.t
| Bracket_Symbol of string

let get_next_of_type argl tau = 
  try 
    let res = List.assoc tau !argl in
    argl := List.remove_assoc tau !argl ;
    res
  with e -> begin
          match tau with
          | Arg_Integer -> Act_Integer Int32.zero
          | Arg_String -> Act_String ""
          | Arg_Object -> Act_Object (empty_object_param ())
          | Arg_Point -> Act_Point(Int32.zero,Int32.zero)
          | Arg_Action -> failwith "arg_action"
          end

let get_next_int argl = 
  match (get_next_of_type argl Arg_Integer) with
    Act_Integer i -> i
  | _ -> failwith "get_next_int" 
let get_next_string argl = 
  match (get_next_of_type argl Arg_String) with
    Act_String i -> i
  | _ -> failwith "get_next_string" 
let get_next_object argl = 
  match (get_next_of_type argl Arg_Object) with
    Act_Object i -> i
  | _ -> failwith "get_next_object" 
let get_next_point argl = 
  match (get_next_of_type argl Arg_Point) with
    Act_Point i -> i
  | _ -> failwith "get_next_point" 

let fixup_concat argl =
  let s1 = get_next_string argl in
  let s2 = get_next_string argl in
  argl := (Arg_String,Act_String(s2^s1)) :: !argl 

let assign_bracket x pos obj iwd2 = 
  if iwd2 then match pos with
  | 0 -> obj.o_ea <- x 
  | 1 -> obj.o_general <- x
  | 2 -> obj.o_race <- x
  | 3 -> obj.o_subrace <- x
  | 4 -> obj.o_class <- x
  | 5 -> obj.o_specific <- x
  | 6 -> obj.o_gender <- x
  | 7 -> obj.o_alignment <- x
  | _ -> failwith "assign to unknown bracket position"
  else match pos with
  | 0 -> obj.o_ea <- x 
  | 1 -> obj.o_general <- x
  | 2 -> obj.o_race <- x
  | 3 -> obj.o_class <- x
  | 4 -> obj.o_specific <- x
  | 5 -> obj.o_gender <- x
  | 6 -> obj.o_alignment <- x
  | _ -> failwith "assign to unknown bracket position"

let assign_compound x pos obj = match pos with
  | 0 -> obj.o_unknown4 <- x
  | 1 -> obj.o_unknown3 <- x
  | 2 -> obj.o_unknown2 <- x
  | 3 -> obj.o_unknown1 <- x
  | 4 -> obj.o_identifiers <- x
  | _ -> failwith "assign to unknown compound position" 

let rec handle_bracket_list al i obj = 
  let iwd2 = (the_game ()).Load.is_iwd2 in 
  match al,i with
  | [],_ -> ()
  | (Bracket_Integer(x)::tl),i -> assign_bracket x i obj iwd2 ; 
      handle_bracket_list tl (i+1) obj
  | (Bracket_Symbol(s)::tl),i -> 
      begin
        try 
          let x = int_of_sym (the_game ()) 
            (ids_file_of_object_position iwd2 i) s in
          assign_bracket x i obj iwd2 ; 
          handle_bracket_list tl (i+1) obj 
        with Not_found -> 
          parse_error (Printf.sprintf 
            "unknown object %s specifier [%s]"
            (ids_file_of_object_position iwd2 i) s )
      end

let rec handle_compound_or_bracket obj cpos_ref arg = match arg with
  | BA_Bracket l -> 
      handle_bracket_list l 0 obj  
  | BA_Compound (s,next_arg) -> 
      begin 
        let x = int_of_sym (the_game ()) "OBJECT" s in 
        handle_compound_or_bracket obj (cpos_ref) next_arg ;
        assign_compound x !cpos_ref obj ;
        decr cpos_ref 
      end 
  | BA_Symbol s -> 
        obj.o_identifiers <- int_of_sym (the_game ()) "OBJECT" s ;
        decr cpos_ref

  | BA_Integer i -> parse_error (Printf.sprintf "expecting compound object specifier or [bracket.object.specifier], got integer %ld" i)
  | BA_String s -> 
        obj.o_name <- s 
  (* parse_error (Printf.sprintf "expecting compound object specifier or [bracket.object.specifier], got string \"%s\"" s) *)

let rec verify_arg_list name al fl = match (al,fl) with 
    [],[] -> []
  | al,[] -> 
  ( try parse_error (Printf.sprintf "Too many arguments to [%s]. Recovering." name) 
    with _ -> [] ) 
  | [],fl -> 
  ( try parse_error (Printf.sprintf "Not enough arguments to [%s]. Recovering." name)
  with _ -> [] ) 
  | (ah::at),(fh::ft) -> 
      begin 
      let act = (match ah,fh.arg_kind with
      | (BA_Integer i), Arg_Integer -> Act_Integer(i)


      | (BA_Bracket([(Bracket_Symbol s)])), Arg_Integer 
      | (BA_String s), Arg_Integer 
      | (BA_Symbol s), Arg_Integer when fh.arg_file <> "" -> 
          begin
            try
              Act_Integer(int_of_sym (the_game ()) fh.arg_file s)
            with _ -> 
              begin
                try
                  Act_Integer(Int32.of_string s)
                with _ -> begin
                (try parse_error (Printf.sprintf 
                  "[%s] argument [%s] not found in [%s.IDS]" name s fh.arg_file)
                 with _ -> ()) ; Act_Integer(Int32.zero) 
                  end
              end 
          end

      | (BA_String s), Arg_Integer -> 
            begin
              try Act_Integer(Int32.of_string s)
              with _ -> Act_Integer(Int32.zero) 
            end 

      | (BA_String s), Arg_String -> Act_String(s) 

      | (BA_String s), Arg_Object ->
        let tmp = empty_object_param () in
        tmp.o_name <- s; 
        Act_Object(tmp)

      | (BA_Bracket _), Arg_Object 
      | (BA_Symbol _), Arg_Object 
      | (BA_Compound _), Arg_Object -> 
        let obj = empty_object_param () in 
        handle_compound_or_bracket obj (ref 4) ah ;
        Act_Object(obj) 

      | (BA_Bracket([Bracket_Integer(x);Bracket_Integer(y)])), 
            Arg_Point -> Act_Point(x,y)

      | (BA_Symbol s), Arg_String ->
        begin
          try parse_error (Printf.sprintf "Type mismatch in \"%s\" argument of [%s].\n\tExpecting type \"%s\". Recovering." fh.arg_comment name (print_arg_kind fh.arg_kind))
          with _ -> Act_String(s)
        end

      | _, _ -> 
        parse_error (Printf.sprintf "Type mismatch in \"%s\" argument of [%s].\n\tExpecting type \"%s\"." fh.arg_comment name (print_arg_kind fh.arg_kind))
      ) in
      (fh.arg_kind,act) :: (verify_arg_list name at ft)
      end 
(* Line 192, file src/bafparser.ml *)
let yytransl_const = [|
  257 (* LPAREN *);
  258 (* RPAREN *);
  259 (* LBRACKET *);
  260 (* RBRACKET *);
  261 (* PERIOD *);
  262 (* COMMA *);
  263 (* ACTIONOVERRIDE *);
  264 (* HASH *);
  265 (* NOT *);
    0 (* EOF *);
  266 (* IF *);
  267 (* THEN *);
  268 (* END *);
  269 (* RESPONSE *);
  270 (* ANYONE *);
    0|]

let yytransl_block = [|
  271 (* STRING *);
  272 (* SYMBOL *);
  273 (* TILDE_STRING *);
  274 (* INTEGER *);
  275 (* TRANS_REF *);
    0|]

let yylhs = "\255\255\
\001\000\004\000\004\000\005\000\002\000\002\000\007\000\009\000\
\009\000\011\000\011\000\012\000\012\000\010\000\010\000\010\000\
\010\000\010\000\010\000\010\000\013\000\013\000\013\000\014\000\
\014\000\016\000\016\000\015\000\015\000\015\000\008\000\008\000\
\006\000\006\000\017\000\003\000\003\000\019\000\019\000\018\000\
\018\000\020\000\000\000\000\000\000\000"

let yylen = "\002\000\
\001\000\000\000\002\000\005\000\000\000\002\000\005\000\000\000\
\002\000\000\000\003\000\000\000\003\000\002\000\001\000\001\000\
\002\000\004\000\001\000\003\000\000\000\002\000\003\000\000\000\
\002\000\000\000\003\000\001\000\001\000\001\000\000\000\001\000\
\000\000\002\000\004\000\000\000\002\000\000\000\001\000\001\000\
\006\000\004\000\002\000\002\000\002\000"

let yydefred = "\000\000\
\000\000\000\000\000\000\000\000\000\000\043\000\001\000\000\000\
\032\000\044\000\000\000\000\000\000\000\000\000\045\000\000\000\
\040\000\000\000\003\000\006\000\000\000\000\000\000\000\037\000\
\000\000\000\000\000\000\016\000\000\000\000\000\015\000\019\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\029\000\
\030\000\028\000\000\000\000\000\000\000\014\000\000\000\000\000\
\000\000\042\000\000\000\009\000\000\000\004\000\034\000\007\000\
\020\000\000\000\025\000\022\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\023\000\013\000\018\000\039\000\041\000\
\011\000\035\000\027\000"

let yydgoto = "\004\000\
\006\000\010\000\015\000\007\000\008\000\037\000\011\000\012\000\
\034\000\035\000\052\000\048\000\046\000\043\000\044\000\059\000\
\038\000\016\000\072\000\017\000"

let yysindex = "\041\000\
\014\255\004\255\000\255\000\000\004\255\000\000\000\000\014\255\
\000\000\000\000\004\255\009\255\033\255\045\255\000\000\000\255\
\000\000\038\255\000\000\000\000\050\255\012\255\012\255\000\000\
\040\255\012\255\021\255\000\000\051\255\052\255\000\000\000\000\
\048\255\054\255\053\255\049\255\046\255\040\255\058\255\000\000\
\000\000\000\000\057\255\059\255\003\255\000\000\047\255\055\255\
\060\255\000\000\012\255\000\000\044\255\000\000\000\000\000\000\
\000\000\021\255\000\000\000\000\063\255\062\255\052\255\065\255\
\053\255\000\255\059\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000"

let yyrindex = "\000\000\
\068\000\002\000\069\000\000\000\022\255\000\000\000\000\068\000\
\000\000\000\000\004\000\000\000\000\000\000\000\000\000\009\000\
\000\000\000\000\000\000\000\000\000\000\000\000\068\255\000\000\
\061\255\068\255\067\255\000\000\008\255\006\255\000\000\000\000\
\000\000\000\000\072\255\000\000\000\000\061\255\000\000\000\000\
\000\000\000\000\000\000\071\255\000\000\000\000\000\000\034\255\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\039\255\001\000\
\072\255\035\255\071\255\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000"

let yygindex = "\000\000\
\000\000\006\000\240\255\070\000\000\000\039\000\000\000\000\000\
\053\000\237\255\015\000\018\000\000\000\000\000\024\000\016\000\
\000\000\000\000\000\000\035\000"

let yytablesize = 278
let yytable = "\024\000\
\038\000\005\000\033\000\005\000\060\000\027\000\013\000\012\000\
\036\000\021\000\018\000\012\000\009\000\021\000\027\000\014\000\
\020\000\028\000\029\000\030\000\031\000\032\000\012\000\005\000\
\021\000\061\000\028\000\029\000\030\000\031\000\032\000\065\000\
\005\000\022\000\040\000\017\000\041\000\031\000\042\000\017\000\
\012\000\001\000\002\000\003\000\012\000\023\000\036\000\036\000\
\025\000\074\000\026\000\045\000\036\000\049\000\047\000\050\000\
\053\000\054\000\051\000\056\000\057\000\066\000\062\000\058\000\
\068\000\069\000\071\000\002\000\036\000\008\000\024\000\063\000\
\033\000\010\000\026\000\014\000\055\000\019\000\039\000\073\000\
\070\000\067\000\075\000\064\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
\000\000\000\000\000\000\000\000\000\000\000\000\000\000\038\000\
\000\000\000\000\000\000\000\000\038\000\038\000\005\000\000\000\
\038\000\031\000\000\000\031\000\036\000\036\000"

let yycheck = "\016\000\
\000\000\000\000\022\000\000\000\002\001\003\001\007\001\002\001\
\000\000\002\001\005\000\006\001\009\001\006\001\003\001\016\001\
\011\000\015\001\016\001\017\001\018\001\019\001\017\001\010\001\
\016\001\045\000\015\001\016\001\017\001\018\001\019\001\051\000\
\011\001\001\001\014\001\002\001\016\001\016\001\018\001\006\001\
\002\001\001\000\002\000\003\000\006\001\001\001\012\001\013\001\
\011\001\066\000\001\001\001\001\013\001\006\001\003\001\002\001\
\008\001\012\001\006\001\002\001\004\001\018\001\016\001\005\001\
\002\001\004\001\002\001\000\000\000\000\002\001\004\001\017\001\
\012\001\002\001\004\001\016\001\038\000\008\000\026\000\065\000\
\063\000\058\000\067\000\049\000\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
\255\255\255\255\255\255\255\255\255\255\255\255\255\255\007\001\
\255\255\255\255\255\255\255\255\012\001\013\001\011\001\255\255\
\016\001\016\001\255\255\016\001\012\001\013\001"

let yynames_const = "\
  LPAREN\000\
  RPAREN\000\
  LBRACKET\000\
  RBRACKET\000\
  PERIOD\000\
  COMMA\000\
  ACTIONOVERRIDE\000\
  HASH\000\
  NOT\000\
  EOF\000\
  IF\000\
  THEN\000\
  END\000\
  RESPONSE\000\
  ANYONE\000\
  "

let yynames_block = "\
  STRING\000\
  SYMBOL\000\
  TILDE_STRING\000\
  INTEGER\000\
  TRANS_REF\000\
  "

let yyact = [|
  (fun _ -> failwith "parser")
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'ifblock_list) in
    Obj.repr((
# 208 "src/bafparser.mly"
                                  _1 ) : Bcs.script))
; (fun parser_env ->
    Obj.repr((
# 211 "src/bafparser.mly"
                                  [] ) : 'ifblock_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'ifblock) in
    let _2 = (peek_val parser_env 0 : 'ifblock_list) in
    Obj.repr((
# 212 "src/bafparser.mly"
                                  _1 :: _2 ) : 'ifblock_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 3 : Bcs.trigger list) in
    let _4 = (peek_val parser_env 1 : 'response_list) in
    Obj.repr((
# 215 "src/bafparser.mly"
                                                   (_2,_4) ) : 'ifblock))
; (fun parser_env ->
    Obj.repr((
# 218 "src/bafparser.mly"
                                  [] ) : Bcs.trigger list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'trigger) in
    let _2 = (peek_val parser_env 0 : Bcs.trigger list) in
    Obj.repr((
# 219 "src/bafparser.mly"
                                  _1 :: _2 ) : Bcs.trigger list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 4 : 'opt_not) in
    let _2 = (peek_val parser_env 3 : string) in
    let _4 = (peek_val parser_env 1 : 'arg_list) in
    Obj.repr((
# 223 "src/bafparser.mly"
   
    let ids = 
      try ids_of_sym (the_game ()) "TRIGGER" _2 
      with _ -> 
      parse_error (Printf.sprintf "[%s] not found in TRIGGER.IDS" _2)
    in 
    let act_list = ref (verify_arg_list _2 _4 ids.i_args) in 
    if is_concat_string ids then
      fixup_concat act_list ; 
    let t1 = get_next_int act_list in
    let t2 = get_next_int act_list in 
    let t3 = get_next_string act_list in
    let t4 = get_next_string act_list in
    let t5 = get_next_object act_list in
    { trigger_id = ids.i_num ; negated = _1 ;
      t_1 = t1; t_2 = t2; unknown = Int32.zero ; t_3 = t3; t_4 = t4; t_5 = t5; 
    } 
  ) : 'trigger))
; (fun parser_env ->
    Obj.repr((
# 243 "src/bafparser.mly"
              [] ) : 'arg_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'arg) in
    let _2 = (peek_val parser_env 0 : 'comma_before_arg_list) in
    Obj.repr((
# 244 "src/bafparser.mly"
                              _1 :: _2 ) : 'arg_list))
; (fun parser_env ->
    Obj.repr((
# 247 "src/bafparser.mly"
                            [] ) : 'comma_before_arg_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'arg) in
    let _3 = (peek_val parser_env 0 : 'comma_before_arg_list) in
    Obj.repr((
# 248 "src/bafparser.mly"
                                    _2 :: _3 ) : 'comma_before_arg_list))
; (fun parser_env ->
    Obj.repr((
# 251 "src/bafparser.mly"
                             "" ) : 'sound_opt))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : string) in
    Obj.repr((
# 252 "src/bafparser.mly"
                             _2 ) : 'sound_opt))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string) in
    let _2 = (peek_val parser_env 0 : 'opt_arg) in
    Obj.repr((
# 256 "src/bafparser.mly"
                  match _2 with 
                    None -> BA_Symbol(_1) 
                  | Some(a) -> BA_Compound(_1,a) ) : 'arg))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Int32.t) in
    Obj.repr((
# 259 "src/bafparser.mly"
                  BA_Integer(_1) ) : 'arg))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr((
# 260 "src/bafparser.mly"
                  BA_String(_1) ) : 'arg))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : string) in
    let _2 = (peek_val parser_env 0 : 'sound_opt) in
    Obj.repr((
# 262 "src/bafparser.mly"
    let result = Dlg.Local_String({ lse_male = _1 ; lse_male_sound = _2; 
                    lse_female = _1; lse_female_sound = _2;}) in 
    (match !Dlg.local_string_ht with
      Some(l) -> if not (List.mem result l ) then 
          Dlg.local_string_ht := Some(result :: l )
    | _ -> () ) ;
    match Dc.resolve_string_while_loading result with
      Dlg.TLK_Index(i) -> BA_Integer(Int32.of_int i)
    | _ -> parse_error (Printf.sprintf "unable to resolve TLK string ~%s~" _1)
  ) : 'arg))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string) in
    let _2 = (peek_val parser_env 2 : 'sound_opt) in
    let _3 = (peek_val parser_env 1 : string) in
    let _4 = (peek_val parser_env 0 : 'sound_opt) in
    Obj.repr((
# 273 "src/bafparser.mly"
    let result = Dlg.Local_String({ lse_male = _1 ; lse_male_sound = _2; 
          lse_female = _3; lse_female_sound = _4; }) in 
    (match !Dlg.local_string_ht with
      Some(l) -> if not (List.mem result l) then 
        Dlg.local_string_ht := Some(result :: l)
    | _ -> () ) ;
    match Dc.resolve_string_while_loading result with
      Dlg.TLK_Index(i) -> BA_Integer(Int32.of_int i)
    | _ -> parse_error (Printf.sprintf "unable to resolve TLK string ~%s~" _1)
  ) : 'arg))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Int32.t) in
    Obj.repr((
# 284 "src/bafparser.mly"
    match Dc.resolve_string_while_loading (Dlg.Trans_String(Int32.to_int _1))
    with Dlg.TLK_Index(i) -> BA_Integer(Int32.of_int i)
    | _ -> parse_error (Printf.sprintf "unable to resolve translation string @%ld" _1)
  ) : 'arg))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'ba_arg_list) in
    Obj.repr((
# 288 "src/bafparser.mly"
                                  BA_Bracket(_2) ) : 'arg))
; (fun parser_env ->
    Obj.repr((
# 291 "src/bafparser.mly"
                  None ) : 'opt_arg))
; (fun parser_env ->
    Obj.repr((
# 292 "src/bafparser.mly"
                  Some(BA_Symbol("Myself")) ) : 'opt_arg))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'arg) in
    Obj.repr((
# 293 "src/bafparser.mly"
                      Some(_2) ) : 'opt_arg))
; (fun parser_env ->
    Obj.repr((
# 296 "src/bafparser.mly"
                  [] ) : 'ba_arg_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'ba_arg) in
    let _2 = (peek_val parser_env 0 : 'period_before_ba_arg_list) in
    Obj.repr((
# 297 "src/bafparser.mly"
                                     _1 :: _2 ) : 'ba_arg_list))
; (fun parser_env ->
    Obj.repr((
# 300 "src/bafparser.mly"
                                [] ) : 'period_before_ba_arg_list))
; (fun parser_env ->
    let _2 = (peek_val parser_env 1 : 'ba_arg) in
    let _3 = (peek_val parser_env 0 : 'period_before_ba_arg_list) in
    Obj.repr((
# 301 "src/bafparser.mly"
                                            _2 :: _3 ) : 'period_before_ba_arg_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : Int32.t) in
    Obj.repr((
# 304 "src/bafparser.mly"
                   Bracket_Integer(_1) ) : 'ba_arg))
; (fun parser_env ->
    Obj.repr((
# 305 "src/bafparser.mly"
                  Bracket_Integer(Int32.zero) ) : 'ba_arg))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : string) in
    Obj.repr((
# 306 "src/bafparser.mly"
                  Bracket_Symbol(_1) ) : 'ba_arg))
; (fun parser_env ->
    Obj.repr((
# 309 "src/bafparser.mly"
              false ) : 'opt_not))
; (fun parser_env ->
    Obj.repr((
# 310 "src/bafparser.mly"
              true ) : 'opt_not))
; (fun parser_env ->
    Obj.repr((
# 313 "src/bafparser.mly"
                    [] ) : 'response_list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'response) in
    let _2 = (peek_val parser_env 0 : 'response_list) in
    Obj.repr((
# 314 "src/bafparser.mly"
                           _1 :: _2 ) : 'response_list))
; (fun parser_env ->
    let _3 = (peek_val parser_env 1 : Int32.t) in
    let _4 = (peek_val parser_env 0 : Bcs.action list) in
    Obj.repr((
# 317 "src/bafparser.mly"
                                               ((Int32.to_int _3),_4) ) : 'response))
; (fun parser_env ->
    Obj.repr((
# 320 "src/bafparser.mly"
                    [] ) : Bcs.action list))
; (fun parser_env ->
    let _1 = (peek_val parser_env 1 : 'complex_action) in
    let _2 = (peek_val parser_env 0 : Bcs.action list) in
    Obj.repr((
# 321 "src/bafparser.mly"
                               _1 :: _2 ) : Bcs.action list))
; (fun parser_env ->
    Obj.repr((
# 324 "src/bafparser.mly"
                                 ) : 'not_actually_optional_rparen))
; (fun parser_env ->
    Obj.repr((
# 325 "src/bafparser.mly"
           ) : 'not_actually_optional_rparen))
; (fun parser_env ->
    let _1 = (peek_val parser_env 0 : 'action) in
    Obj.repr((
# 328 "src/bafparser.mly"
                          _1 ) : 'complex_action))
; (fun parser_env ->
    let _3 = (peek_val parser_env 3 : 'arg) in
    let _5 = (peek_val parser_env 1 : 'action) in
    let _6 = (peek_val parser_env 0 : 'not_actually_optional_rparen) in
    Obj.repr((
# 330 "src/bafparser.mly"
    let base_action = _5 in 
    let act_list = ref (verify_arg_list "ActionOverride" [_3] 
      [ { arg_kind = Arg_Object ; arg_comment = "Actor" ; arg_file = "" } ])
    in 
    let actor = get_next_object act_list in
    base_action.a_1 <- actor ;
    base_action 
  ) : 'complex_action))
; (fun parser_env ->
    let _1 = (peek_val parser_env 3 : string) in
    let _3 = (peek_val parser_env 1 : 'arg_list) in
    Obj.repr((
# 341 "src/bafparser.mly"
   
    let ids = 
      try ids_of_sym (the_game ()) "ACTION" _1 
      with _ -> 
      parse_error (Printf.sprintf "[%s] not found in ACTION.IDS" _1)
    in 
    let act_list = ref (verify_arg_list _1 _3 ids.i_args) in 
    if is_concat_string ids then
      fixup_concat act_list ; 
    let a1 = empty_object_param() in 
    let a2 = get_next_object act_list in
    let a3 = get_next_object act_list in
    let a4 = get_next_int act_list in
    let a5 = get_next_point act_list in
    let a6 = get_next_int act_list in
    let a7 = get_next_int act_list in
    let a8 = get_next_string act_list in
    let a9 = get_next_string act_list in
    {
      action_id = ids.i_num ;
      a_1 = a1; a_2 = a2; a_3 = a3; a_4 = a4; a_5 = a5;
      a_6 = a6; a_7 = a7; a_8 = a8; a_9 = a9; 
    } 
  ) : 'action))
(* Entry baf_file *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
(* Entry trigger_list *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
(* Entry action_list *)
; (fun parser_env -> raise (YYexit (peek_val parser_env 0)))
|]
let yytables =
  { actions=yyact;
    transl_const=yytransl_const;
    transl_block=yytransl_block;
    lhs=yylhs;
    len=yylen;
    defred=yydefred;
    dgoto=yydgoto;
    sindex=yysindex;
    rindex=yyrindex;
    gindex=yygindex;
    tablesize=yytablesize;
    table=yytable;
    check=yycheck;
    error_function=parse_error;
    names_const=yynames_const;
    names_block=yynames_block }
let baf_file (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 1 lexfun lexbuf : Bcs.script)
let trigger_list (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 2 lexfun lexbuf : Bcs.trigger list)
let action_list (lexfun : Lexing.lexbuf -> token) (lexbuf : Lexing.lexbuf) =
   (yyparse yytables 3 lexfun lexbuf : Bcs.action list)
